@@ -1,5 +1,5 @@
 /* crypto-3des.c --- 3DES crypto functions.
- * Copyright (C) 2002, 2003, 2004  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2006  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -121,7 +121,7 @@ des3none_decrypt (Shishi * handle,
 }
 
 static void
-des_set_odd_key_parity (unsigned char key[8])
+des_set_odd_key_parity (char key[8])
 {
   int i, j;
 
@@ -162,7 +162,7 @@ static int
 des3_random_to_key (Shishi * handle,
 		    const char *rnd, size_t rndlen, Shishi_key * outkey)
 {
-  unsigned char tmpkey[3 * 8];
+  char tmpkey[3 * 8];
   int i;
 
   if (rndlen < 168 / 8)
