@@ -27,7 +27,7 @@
 #include <time.h>		/* time_t */
 #include <shishi-int.h>		/* uint32_t */
 
-#define SHISHI_VERSION "0.0.27"
+#define SHISHI_VERSION "0.0.29"
 
 /* Error codes */
 typedef enum
@@ -85,7 +85,8 @@ typedef enum
   SHISHI_ENCAPREPPART_BAD_KEYTYPE = 50,
   SHISHI_GETTIMEOFDAY_ERROR = 51,
   SHISHI_KEYTAB_ERROR = 52,
-  SHISHI_LAST_ERROR = 52
+  SHISHI_CCACHE_ERROR = 53,
+  SHISHI_LAST_ERROR = 53
 }
 Shishi_rc;
 
@@ -854,6 +855,24 @@ extern Shishi_tkt *shishi_tkts_get_for_localservicepasswd (Shishi_tkts * tkts,
 							   const char
 							   *passwd);
 
+/* tktccache.c */
+extern char *shishi_tkts_default_ccache_guess (Shishi * handle);
+extern const char *shishi_tkts_default_ccache (Shishi * handle);
+extern void shishi_tkts_default_ccache_set (Shishi * handle,
+					    const char *ccache);
+extern int shishi_tkts_add_ccache_mem (Shishi * handle,
+				       const char *data, size_t len,
+				       Shishi_tkts *tkts);
+extern int shishi_tkts_add_ccache_file (Shishi * handle,
+					const char *filename,
+					Shishi_tkts *tkts);
+extern int shishi_tkts_from_ccache_mem (Shishi * handle,
+					const char *data, size_t len,
+					Shishi_tkts **outtkts);
+extern int shishi_tkts_from_ccache_file (Shishi * handle,
+					 const char *filename,
+					 Shishi_tkts **outtkts);
+
 /* diskio.c */
 extern int
 shishi_enckdcreppart_print (Shishi * handle,
@@ -1259,9 +1278,18 @@ extern int shishi_enckdcreppart_nonce_set (Shishi * handle,
 extern int shishi_enckdcreppart_flags_set (Shishi * handle,
 					   Shishi_asn1 enckdcreppart,
 					   int flags);
+extern int shishi_enckdcreppart_authtime_set (Shishi * handle,
+					     Shishi_asn1 enckdcreppart,
+					     const char *authtime);
+extern int shishi_enckdcreppart_starttime_set (Shishi * handle,
+					     Shishi_asn1 enckdcreppart,
+					     const char *starttime);
 extern int shishi_enckdcreppart_endtime_set (Shishi * handle,
 					     Shishi_asn1 enckdcreppart,
 					     const char *endtime);
+extern int shishi_enckdcreppart_renew_till_set (Shishi * handle,
+						Shishi_asn1 enckdcreppart,
+						const char *renew_till);
 extern int shishi_enckdcreppart_srealm_set (Shishi * handle,
 					    Shishi_asn1 enckdcreppart,
 					    const char *srealm);
@@ -1392,6 +1420,8 @@ extern const char *shishi_generalize_now (Shishi * handle);
 extern time_t shishi_generalize_ctime (Shishi * handle, const char *t);
 extern int shishi_time (Shishi * handle, Shishi_asn1 node,
 			const char *field, char **t);
+extern int shishi_ctime (Shishi * handle, Shishi_asn1 node,
+			 const char *field, time_t *t);
 
 /* nettle.c, libgcrypt.c, ... */
 extern int shishi_randomize (Shishi * handle, int strong,
@@ -1538,11 +1568,11 @@ extern int shishi_verify (Shishi * handle,
 			  const char *cksum, size_t cksumlen);
 extern int shishi_dk (Shishi * handle,
 		      Shishi_key * key,
-		      const char *constant, size_t constantlen,
+		      const char *prfconstant, size_t prfconstantlen,
 		      Shishi_key * derivedkey);
 extern int shishi_dr (Shishi * handle,
 		      Shishi_key * key,
-		      const char *constant, size_t constantlen,
+		      const char *prfconstant, size_t prfconstantlen,
 		      char *derivedrandom, size_t derivedrandomlen);
 extern int shishi_n_fold (Shishi * handle, const char *in, size_t inlen,
 			  char *out, size_t outlen);
